@@ -56,3 +56,18 @@ class IdpPageOpenedOnClick(Exception):
 class WebDriverInitialisationException(Exception):
     def __init__(self, e):
         self.thrown_exception = e
+
+
+class ScreenshotException(Exception):
+    def __init__(self, domain_url, login_url, message="It was not possible to generate a screenshot!"):
+        """Exception raised for errors during the screenshot recording.
+
+        Attributes:
+            domain_url -- domain of the tranco list
+            login_url -- login URL of the website
+            message -- exception message
+        """
+        self.domain_url = domain_url
+        self.login_url = login_url
+        self.message = message
+        super().__init__(self.message)
