@@ -1,6 +1,6 @@
 from .locateloginpages.locate_login_page_process import LocateLoginPage
-from .ssoanalysis.sso_detection_service import SSODetectionService
-from .ssoanalysis.sso_detection_process import SSODetectionProcess
+from .ssolandscapeanalysis.sso_detection_service import SSODetectionService
+from .ssolandscapeanalysis.sso_detection_process import SSODetectionProcess
 from .privacydetection.privacy_detection_process import PrivacyDetectionProcess
 from .privacydetection.privacy_detection_provider import PrivacyDetectionProvider
 from .process_helper import ProcessHelper
