@@ -89,12 +89,13 @@ class ProcessHelper:
             if analysis_run_type == ProcessType.AUTOMATIC_SSO_DETECTION_BY_SEARCH_ENGINE:
                 from model.ssodetection.search_engine import SearchEngine
                 from processes.ssolandscapeanalysis.sso_detection_process import SSODetectionProcess
-                logger.info(
-                    "Request algorithm(s) and engine(s) for automatic analysis with search engine and count of websites")
+                logger.info("Request algorithm(s), engine(s), and provider(s) for automatic analysis with search "
+                            "engine and count of websites")
                 raw_ses = rc.get_search_engine_mode_for_run(analysis_id)[1:-1].split(",")
                 count_of_websites = rc.get_additional_analysis_run_information(analysis_id,
                                                                                "COUNT_OF_WEBSITES_TO_ANALYSE_PER_SEARCH_ENGINE")
                 raw_alg = rc.get_search_algorithms_for_run(analysis_id)
+                raw_provider = rc.get_provider_for_sso_detection(analysis_id)[1:-1].split(", ")
                 if raw_alg is None:
                     raw_alg = ["KEYWORD_ANALYSIS", "IMAGE_ANALYSIS"]
                 else:
@@ -105,14 +106,32 @@ class ProcessHelper:
                     count_of_websites = 3
                 ses = []
                 alg = []
+                prov = []
                 for i in range(0, len(raw_ses)):
                     ses.append(SearchEngine[raw_ses[i].strip()])
                 for i in range(0, len(raw_alg)):
                     alg.append(SearchAlgorithm[raw_alg[i].strip()])
-                analysis_process = SSODetectionProcess(backend_info, analysis_id, analysis_run_type, ses,
+                for prov_index in raw_provider:
+                    prov.append(rc.get_provider_name_for_index(prov_index))
+                analysis_process = SSODetectionProcess(backend_info, analysis_id, analysis_run_type, prov, ses,
                                                        count_of_websites, alg)
-            elif analysis_run_type == ProcessType.AUTOMATIC_SSO_DETECTION \
-                    or analysis_run_type == ProcessType.MANUAL_SSO_DETECTION:
+            elif analysis_run_type == ProcessType.AUTOMATIC_SSO_DETECTION:
+                from processes.ssolandscapeanalysis.sso_detection_process import SSODetectionProcess
+                logger.info("Request algorithm(s) and provider(s) for automatic analysis")
+                raw_alg = rc.get_search_algorithms_for_run(analysis_id)
+                raw_provider = rc.get_provider_for_sso_detection(analysis_id)[1:-1].split(", ")
+                if raw_alg is None:
+                    raw_alg = ["KEYWORD_ANALYSIS", "IMAGE_ANALYSIS"]
+                else:
+                    raw_alg = raw_alg[1:-1].split(",")
+                alg = []
+                prov = []
+                for prov_index in raw_provider:
+                    prov.append(rc.get_provider_name_for_index(prov_index))
+                for i in range(0, len(raw_alg)):
+                    alg.append(SearchAlgorithm[raw_alg[i].strip()])
+                analysis_process = SSODetectionProcess(backend_info, analysis_id, analysis_run_type, prov, None, 3, alg)
+            elif analysis_run_type == ProcessType.MANUAL_SSO_DETECTION:
                 from processes.ssolandscapeanalysis.sso_detection_process import SSODetectionProcess
                 analysis_process = SSODetectionProcess(backend_info, analysis_id, analysis_run_type)
             elif analysis_run_type == ProcessType.PRIVACY_DETECTION:
