@@ -34,8 +34,9 @@ if not os.path.exists(temp_folder):
     os.makedirs(temp_folder)
 
 
-def thread_process(site, backend_info: BackendInformation, process_type: ProcessType, search_engines: list,
-                   analysis_run_id: int, count_of_websites_to_analyze_per_website: int, search_algorithms: list):
+def thread_process(site, backend_info: BackendInformation, process_type: ProcessType, providers: list,
+                   search_engines: list, analysis_run_id: int, count_of_websites_to_analyze_per_website: int,
+                   search_algorithms: list):
     success = False
     rest_client = None
     chromedriver = None
@@ -50,7 +51,8 @@ def thread_process(site, backend_info: BackendInformation, process_type: Process
         rest_client = RestClient(backend_info.host, backend_info.port, backend_info.token)
         known_sso_provider = rest_client.get_known_sso_provider()
         start_time = time.time()
-        logger.info("Received site " + site.base_page + " to analyse. Starting chromedriver...")
+        logger.info("Received site " + site.base_page + " to analyse the following sso providers: " + str(
+            providers) + ". Starting chromedriver...")
         rest_client.update_progress_of_analysis(analysis_run_id, site.base_page, 0, "Starting chromedriver")
         chromedriver = None
         if process_type == ProcessType.AUTOMATIC_SSO_DETECTION_BY_SEARCH_ENGINE:
@@ -101,6 +103,7 @@ def thread_process(site, backend_info: BackendInformation, process_type: Process
             rest_client.update_progress_of_analysis(analysis_run_id, site.base_page, 20,
                                                     "Loading login page from brain")
             latest_login_infos = [rest_client.get_latest_login_location_for_page_by_page_id(site.index)]
+            login_candidates.append({'engine': "BRAIN", 'site': latest_login_infos[0].loginPath})
         time_login_site_detection = time.time() - time_login_site_detection
         # Finished Login Gathering
         if chromedriver is not None:
@@ -152,19 +155,8 @@ def thread_process(site, backend_info: BackendInformation, process_type: Process
                     rest_client.update_progress_of_analysis(analysis_run_id, site.base_page,
                                                             last_progress + ((steps / 1.5) / max * step), status)
 
-                search_for_google = not ProcessHelper.contain_results_provider(results, "google", known_sso_provider)
-                if not search_for_google:
-                    logger.info("Google SSO Support already found. Skipping it in analysis")
-                search_for_facebook = not ProcessHelper.contain_results_provider(results, "facebook",
-                                                                                 known_sso_provider)
-                if not search_for_facebook:
-                    logger.info("Facebook SSO Support already found. Skipping it in analysis")
-                search_for_apple = not ProcessHelper.contain_results_provider(results, "apple", known_sso_provider)
-                if not search_for_apple:
-                    logger.info("Apple SSO Support already found. Skipping it in analysis")
-
                 ids = gather_sso_support(known_sso_provider, latest_login_info, chromedriver, process_type,
-                                         search_for_google, search_for_facebook, search_for_apple, progress_callback)
+                                         providers, results, progress_callback)
                 logger.info("Keyword based (or manual) analysis finished for " + latest_login_info.loginPath +
                             ". Exporting har and stopping chromedriver")
                 file_counter += 1
@@ -196,6 +188,10 @@ def thread_process(site, backend_info: BackendInformation, process_type: Process
         # IMAGE ANALYSIS
         time_image_analysis = time.time()
         image_analysis_percent = 30
+        # This is just till the logo recognition is capable of handling dynamic sso provider
+        search_for_google = providers.__contains__("GOOGLE")
+        search_for_facebook = providers.__contains__("FACEBOOK")
+        search_for_apple = providers.__contains__("APPLE")
         if search_algorithms is not None and search_algorithms.__contains__(SearchAlgorithm.IMAGE_ANALYSIS):
             logger.info("Starting logo detection analysis")
             urls_to_analyse = []
@@ -211,9 +207,9 @@ def thread_process(site, backend_info: BackendInformation, process_type: Process
             res_logo = logoR.analyseHybridLoginURL(
                 domain_url=site.base_page.replace("https://", "").replace("http://", ""), login_urls=urls_to_analyse,
                 init_recognition={
-                    "facebook": ProcessHelper.contain_results_provider(results, "facebook", known_sso_provider),
-                    "google": ProcessHelper.contain_results_provider(results, "google", known_sso_provider),
-                    "apple": ProcessHelper.contain_results_provider(results, "apple", known_sso_provider)},
+                    "facebook": ProcessHelper.contain_results_provider(results, "facebook", known_sso_provider) or not search_for_facebook,
+                    "google": ProcessHelper.contain_results_provider(results, "google", known_sso_provider) or not search_for_google,
+                    "apple": ProcessHelper.contain_results_provider(results, "apple", known_sso_provider) or not search_for_apple},
                 callback=progress_callback_image_analysis)
 
             for r in res_logo["details"]:
@@ -339,13 +335,13 @@ def wait_and_gather_screenshot_if_necessary(chromedriver, process_type):
     return None
 
 
-def gather_sso_support(known_sso_provider, latest_login_info, chromedriver, process_type, google=True, facebook=True,
-                       apple=True, progress_callback=None):
+def gather_sso_support(known_sso_provider, latest_login_info, chromedriver, process_type, providers_to_detect, results,
+                       progress_callback=None):
     logger.info("Starting SSO Detection algorithm")
     service = SSODetectionService(known_sso_provider)
     if process_type == ProcessType.AUTOMATIC_SSO_DETECTION or process_type == ProcessType.AUTOMATIC_SSO_DETECTION_BY_SEARCH_ENGINE:
-        results = service.automatic_sso_detection(chromedriver, latest_login_info, progress_callback, google, facebook,
-                                                  apple)
+        results = service.automatic_sso_detection(chromedriver, latest_login_info, providers_to_detect, results,
+                                                  known_sso_provider, progress_callback)
     else:
         results = service.manual_sso_detection()
     return results
@@ -390,7 +386,7 @@ def save_supported_sso_provider(site, results, har_files, process_type, rest_cli
 class SSODetectionProcess(GenericAnalysisProcess):
 
     def __init__(self, backend_info: BackendInformation, analysis_run_id: int, process_type: ProcessType,
-                 search_engines: list = None, count_of_websites_to_analyze_per_website: int = 3,
+                 providers: list = None, search_engines: list = None, count_of_websites_to_analyze_per_website: int = 3,
                  search_algorithms: list = None):
         if not [ProcessType.AUTOMATIC_SSO_DETECTION_BY_SEARCH_ENGINE, ProcessType.AUTOMATIC_SSO_DETECTION,
                 ProcessType.MANUAL_SSO_DETECTION].__contains__(process_type):
@@ -402,6 +398,7 @@ class SSODetectionProcess(GenericAnalysisProcess):
         self.process_type = process_type
         self.count_of_websites_to_analyze_per_website = count_of_websites_to_analyze_per_website
         self.search_algorithms = search_algorithms
+        self.providers = providers
 
     def prepare(self):
         ProcessHelper.check_for_unfinished_work(self.rest_client)
@@ -411,5 +408,5 @@ class SSODetectionProcess(GenericAnalysisProcess):
 
     def generate_process(self, object_to_analyse) -> Process:
         return Process(target=thread_process, args=(
-            object_to_analyse, self.backend_info, self.process_type, self.search_engines, self.analysis_run_id,
-            self.count_of_websites_to_analyze_per_website, self.search_algorithms))
+            object_to_analyse, self.backend_info, self.process_type, self.providers, self.search_engines,
+            self.analysis_run_id, self.count_of_websites_to_analyze_per_website, self.search_algorithms))
