@@ -351,16 +351,10 @@ def process_function(sso_detection, backend_info: BackendInformation, analysis_r
                                                                             int(65 + (20 * (step / max))), status)
 
             def special_check(d):
-                return wait_for_result(d, social_login_info, 15)[0]
+                return wait_for_result(d, social_login_info, 15)
 
-            run_google = social_login_info['name'] == "Google"
-            run_facebook = social_login_info['name'] == "Facebook"
-            run_apple = social_login_info['name'] == 'Apple'
-            if not run_google and not run_facebook and not run_apple:
-                logger.error("Something went wrong when falling back to element location! Neither google, facebook"
-                             ", nor apple were requested")
-            rawres = service.automatic_sso_detection(chromedriver, mock_latest_login_info, progress_callback,
-                                                     run_google, run_facebook, run_apple, special_check)[0]
+            rawres = service.automatic_sso_detection(chromedriver, mock_latest_login_info, [social_login_info['name']],
+                                                     [], [], progress_callback, special_check, True)[0]
             result = wait_for_result(chromedriver, social_login_info)
             if result[0] is True:
                 logger.info("Fallback located element successfully, saving results")
