@@ -20,6 +20,7 @@ class RestClient:
     path_tranco_entries_between = "/rest/tranco/between"
     path_get_tranco_id_for_site = "/rest/tranco/idforsite"
     path_known_sso_providers = "/rest/knownproviders/all"
+    path_provider_name_for_index = "/rest/knownproviders/byindex"
     path_file_upload_login_path_detection = "/rest/files/loginlocationdetection"
     path_post_timing_results = "/rest/timing/new"
 
@@ -125,6 +126,13 @@ class RestClient:
         response = self.send_get_request(self.path_known_sso_providers)
         return RestHelper.convert_json_to_list_of_sso_provider(response)
 
+    def get_provider_name_for_index(self, prov_index):
+        response = self.send_get_request(self.path_provider_name_for_index, {'index': str(prov_index)})
+        if response.status_code == 200:
+            return response.text
+        logger.error("Something went wrong. Could not get provider name for index " + str(prov_index))
+        raise Exception("Could not get provider name for index " + str(prov_index))
+
     def post_timing_results(self, analysis_run_id, base_page, time_login_site_detection, time_keyword_based_analysis,
                             time_image_analysis, time_combined_analyses, time_complete_process,
                             time_complete_process_with_upload, sites_analysed):
@@ -277,6 +285,8 @@ class RestClient:
                 files.append(('screenshot', result['screen']))
         if len(files) > 0:
             logger.info("Upload size of files (har, screen, ...): " + str(size * 0.000001) + " MB")
+        if len(files) == 0:
+            files = dict(mock='file')  # Forcing multipart upload
         response = self.send_post_request_with_files(self.path_save_sso_analysis, post_data, files)
         if response.status_code == 200 and response.text == "success":
             logger.info("File uploaded successfully!")
@@ -294,6 +304,9 @@ class RestClient:
     def get_search_algorithms_for_run(self, run_id):
         return self.get_additional_analysis_run_information(run_id, "SEARCH_ALGORITHM")
 
+    def get_provider_for_sso_detection(self, run_id):
+        return self.get_additional_analysis_run_information(run_id, "KNOWN_SSO_PROVIDER")
+
     # endregion
 
     # region Privacy Detection
@@ -469,7 +482,8 @@ class RestClient:
         logger.error("Something went wrong (code " + str(response.status_code) + ")")
         return None
 
-    def extract_response_as_json(self, response):
+    @staticmethod
+    def extract_response_as_json(response):
         if response.status_code == 200:
             if response.text is not None and len(response.text) != 0:
                 return response.json()
@@ -567,3 +581,4 @@ class RestClient:
             raise error
 
     # endregion
+
