@@ -110,6 +110,7 @@ def run():
             logger.info("Got token. Client is initialized")
             rest_client = RestClient(args.server_host, args.server_port, token)
             logger.info("Checking unfinished work")
+            ProcessHelper.check_for_unfinished_work(rest_client)
             logger.info("Waiting for job...")
             prev_job_id = '-1'
             running_check = threading.Event()
@@ -119,7 +120,7 @@ def run():
             invalid_config_error_check = threading.Event()
             invalid_config_error_check.set()
             job = None
-            stopping_reason = "Shutdown"
+            stopping_reason = "Unknown!"
             try:
                 while True:
                     remote_version = rest_client.get_remote_client_version()
@@ -132,10 +133,12 @@ def run():
                     current_job_id = rest_client.get_job_for_daemon_client()
                     if current_job_id == "-1000":
                         logger.info("Received shutdown command! Will initialize shutdown...")
+                        stopping_reason = "Shutdown"
                         break
                     if current_job_id is None:
                         logger.error("Looks like this client was not cleanly removed from the brain (please stop this "
                                      "client before removing it from the brain). Shutting down...")
+                        stopping_reason = "Shutdown due to unclean removal"
                         break
                     rest_client.send_daemon_ping()
                     current_activity = "Idle"
@@ -165,6 +168,8 @@ def run():
                             running_check.set()
                             job.start()
                         prev_job_id = current_job_id
+            except Exception as e:
+                stopping_reason = e.__class__.__name__
             finally:
                 logger.info("Stopping daemon...")
                 stop_job(job, rest_client, running_check)
